@@ -19,6 +19,25 @@ if __name__ == "__main__":
 
 d = docker.DockerClient(base_url="unix://var/run/docker.sock")
 
+yaml = """
+ExmaplePipeline:
+    - name: helloworld
+      image_repo: hello-world
+      sidecars:
+        - name: redis01
+          image_repo: redis
+      dependencies:
+        - random-logs
+    - name: random-logs
+      image_repo: chentex/random-logger
+      command:
+        - 1000
+        - 4000
+        - 100
+      labels: 
+        mylabel: True
+"""
+'''
 yaml = """
 ExmaplePipeline:
     - name: test01
@@ -30,7 +49,7 @@ ExmaplePipeline:
         - name: redis01
           image_repo: redis
 """
-
+'''
 
 '''
 yaml = """
@@ -74,9 +93,9 @@ p.run()
 
 # Optional define custom service schedule (https://schedule.readthedocs.io)
 # default is once a day at 00:00
-p.service_schedule = schedule.every(30).seconds.do(p.run_service_containers)
+#p.service_schedule = schedule.every(30).seconds.do(p.run_service_containers)
 
 # Step into service mode
-p.start_service_mode()
+#p.start_service_mode()
 
 # now servicecontainer01 will run every 30 seconds
